:mod:`stix.exploit_target.weakness` Module
==========================================

.. module:: stix.exploit_target.weakness

Overview
--------
The :mod:`stix.exploit_target.weakness` module captures a given software weakness as enumerated by CWE


Classes
-------

.. autoclass:: Weakness
	:show-inheritance:
	:members:
